@@ -4,6 +4,7 @@ from time import time
 from typing import Any
 from typing import Optional
 from typing import Union
+from urllib.parse import quote
 from urllib.robotparser import RobotFileParser
 
 from .connection import CloudflareScraper
@@ -207,7 +208,7 @@ class FAAPI:
         :param user: The name of the user (_ characters are allowed).
         :return: A User object.
         """
-        return User(self.get_parsed(join_url("user", username_url(user))))
+        return User(self.get_parsed(join_url("user", quote(username_url(user)))))
 
     # noinspection DuplicatedCode
     def gallery(self, user: str, page: int = 1) -> tuple[list[SubmissionPartial], Optional[int]]:
@@ -218,7 +219,7 @@ class FAAPI:
         :param page: The page to fetch.
         :return: A list of SubmissionPartial objects and the next page (None if it is the last).
         """
-        page_parsed: BeautifulSoup = self.get_parsed(join_url("gallery", username_url(user), int(page)))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("gallery", quote(username_url(user)), int(page)))
         info_parsed: dict[str, Any] = parse_user_submissions(page_parsed)
         author: UserPartial = UserPartial()
         author.name, author.status, author.title, author.join_date, author.user_icon_url = [
@@ -239,7 +240,7 @@ class FAAPI:
         :param page: The page to fetch.
         :return: A list of SubmissionPartial objects and the next page (None if it is the last).
         """
-        page_parsed: BeautifulSoup = self.get_parsed(join_url("scraps", username_url(user), int(page)))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("scraps", quote(username_url(user)), int(page)))
         info_parsed: dict[str, Any] = parse_user_submissions(page_parsed)
         author: UserPartial = UserPartial()
         author.name, author.status, author.title, author.join_date, author.user_icon_url = [
@@ -259,7 +260,7 @@ class FAAPI:
         :param page: The page to fetch.
         :return: A list of SubmissionPartial objects and the next page (None if it is the last).
         """
-        page_parsed: BeautifulSoup = self.get_parsed(join_url("favorites", username_url(user), page.strip()))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("favorites", quote(username_url(user)), page.strip()))
         info_parsed: dict[str, Any] = parse_user_favorites(page_parsed)
         submissions: list[SubmissionPartial] = list(map(SubmissionPartial, info_parsed["figures"]))
         return submissions, info_parsed["next_page"] or None
@@ -272,7 +273,7 @@ class FAAPI:
         :param page: The page to fetch.
         :return: A list of Journal objects and the next page (None if it is the last).
         """
-        page_parsed: BeautifulSoup = self.get_parsed(join_url("journals", username_url(user), int(page)))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("journals", quote(username_url(user)), int(page)))
         info_parsed: dict[str, Any] = parse_user_journals(page_parsed)
         author: UserPartial = UserPartial()
         author.name, author.status, author.title, author.join_date, author.user_icon_url = [
@@ -294,7 +295,7 @@ class FAAPI:
         """
         users: list[UserPartial] = []
         us, np = parse_watchlist(
-            self.get_parsed(join_url("watchlist", "to", username_url(user), page), skip_auth_check=True))
+            self.get_parsed(join_url("watchlist", "to", quote(username_url(user)), page), skip_auth_check=True))
         for s, u in us:
             _user: UserPartial = UserPartial()
             _user.name = u
@@ -311,7 +312,7 @@ class FAAPI:
         """
         users: list[UserPartial] = []
         us, np = parse_watchlist(
-            self.get_parsed(join_url("watchlist", "by", username_url(user), page), skip_auth_check=True))
+            self.get_parsed(join_url("watchlist", "by", quote(username_url(user)), page), skip_auth_check=True))
         for s, u in us:
             _user: UserPartial = UserPartial()
             _user.name = u
